@@ -19,10 +19,25 @@ Common non-standard MIME encodings for this:
 
     x-gzip64
 
+Since this class relies on external programs which may not
+exist on your machine, MIME-tools does not "install" it by default.  
+To use it, you need to say in your main program:
+
+    install MIME::Decoder::Gzip64 'x-gzip64';
+
+Note: if this class isn't working for you, you may need to change
+the commands it runs.  In your main program, you can do so
+by setting up the two commands which 
+
+    use MIME::Decoder::Gzip64;
+     
+    $MIME::Decoder::Gzip64::GZIP   = 'gzip -c';
+    $MIME::Decoder::Gzip64::GUNZIP = 'gzip -d -c';
+
 
 =head1 AUTHOR
 
-Copyright (c) 1996, 1997 by Eryq / eryq@zeegee.com
+Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
 
 All rights reserved.  This program is free software; you can redistribute 
 it and/or modify it under the same terms as Perl itself.
@@ -30,23 +45,31 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision: 4.103 $ $Date: 1998/01/10 04:24:07 $
+$Revision: 4.105 $ $Date: 1999/02/09 03:32:49 $
 
 =cut
 
 
 require 5.002;
-use vars qw(@ISA $VERSION);
+use vars qw(@ISA $VERSION $ZIP $UNZIP);
 use MIME::Decoder;
 use MIME::Base64;
 use MIME::Decoder::Base64;
 use MIME::ToolUtils qw(tmpopen whine);
 use IO::Wrap;
 
+# Inheritance:
 @ISA = qw(MIME::Decoder::Base64);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4.103 $, 10;
+$VERSION = substr q$Revision: 4.105 $, 10;
+
+# How to compress stdin to stdout:
+$GZIP   = "gzip -c";
+
+# How to UNcompress stdin to stdout:
+$GUNZIP = "gzip -d -c";
+
 
 #------------------------------
 #
@@ -59,14 +82,11 @@ sub decode_it {
     my $tmp = wraphandle(tmpopen() || die "can't get temp file");
 
     # Stage 1: decode the base64'd stream into zipped data:
-    $self->SUPER::decode_it($in, $tmp) 
-	or die "base64 decoding failed!";
+    $self->SUPER::decode_it($in, $tmp)    or die "base64 decoding failed!";
     
     # Stage 2: un-zip the zipped data:
     $tmp->seek(0, 0); 
-    $self->filter($tmp, $out, "gzip -d -") 
-	or die "gzip decoding failed!";
-    1;
+    $self->filter($tmp, $out, $GUNZIP)    or die "gzip decoding failed!";
 }
 
 #------------------------------
@@ -81,16 +101,12 @@ sub encode_it {
     my $tmp = wraphandle(tmpopen() || die "can't get temp file");
   
     # Stage 1: zip the raw data:
-    $self->filter($in, $tmp, "gzip -") 
-	or die "gzip encoding failed!";
+    $self->filter($in, $tmp, $GZIP)       or die "gzip encoding failed!";
     
     # Stage 2: encode the zipped data via base64:
     $tmp->seek(0, 0);    
-    $self->SUPER::encode_it($tmp, $out) 
-	or die "base64 encoding failed!";
-    1;
+    $self->SUPER::encode_it($tmp, $out)   or die "base64 encoding failed!";
 }
 
 #------------------------------
 1;
-
